/**
 * This file is distributed as part of the code accompanying the paper:
 *
 * "Robust Region Detection via Consensus Segmentation of Deformable Shapes"
 * E. Rodola, S. Rota Bulo, and D. Cremers
 * Computer Graphics Forum, 33(5), 2014
 *
 * If you use this code, please cite the paper above.
 *
 * Samuel Rota Bulò (c) 2014
 */
#include "mex.h"
#include "consensus.h"

void mexFunction(int nlhs, mxArray *plhs[ ],int nrhs, const mxArray *prhs[ ]) 
{
  // CHECK n. of input and output arguments
  if(nrhs<5 || nlhs==0)
  {
    mexErrMsgTxt("Required 5 arguments in input and at least 1 in output.");
    return;
  }

  /* PROCESS INPUT ARGUMENTS */
  double *pC=mxGetPr(prhs[0]);
  double *pN=mxGetPr(prhs[1]);
  int n=mxGetN(prhs[0]);
  
  if(mxGetM(prhs[0])!=n || mxGetN(prhs[1])!=n || mxGetM(prhs[1])!=n)
  {
    mexErrMsgTxt("First two arguments should be two square matrices of equal size");
    return;
  }
  
  Map<MatrixXd> C(pC,n,n);
  Map<MatrixXd> N(pN,n,n);

  double *nClassesPr=mxGetPr(prhs[2]);
  
  double *tollPr=mxGetPr(prhs[3]);
  double *maxIterPr=mxGetPr(prhs[4]);

  int k=(int)*nClassesPr;
  double toll=*tollPr;
  int maxIter=(int)*maxIterPr;

  /******************************/

  /* PROCESS OUTPUT ARGUMENTS */
  plhs[0]=mxCreateDoubleMatrix(k,n,mxREAL);
  double *pY=mxGetPr(plhs[0]);

  Map<MatrixXd> Y(pY,k,n);
  /******************************/
  int niter;
  double err;
  cvlab::PPC_l2(C,N,Y,k,toll,maxIter,niter,err);
  
  plhs[1] = mxCreateDoubleMatrix(1,1,mxREAL);
  double* it = mxGetPr(plhs[1]);
  *it = niter;
  
  plhs[2] = mxCreateDoubleMatrix(1,1,mxREAL);
  double* e = mxGetPr(plhs[2]);
  *e = err;
}
