%
% This code implements the method described in:
%
% "Robust Region Detection via Consensus Segmentation of Deformable Shapes"
% E. Rodola, S. Rota Bulo, and D. Cremers
% Computer Graphics Forum, 33(5), 2014
%
% If you use this code, please cite the paper above.
% 
% Emanuele Rodola (c) 2014
% rodola@in.tum.de
%%
close all, clear all
warning ON

addpath('./tools/');
addpath('./consensus/');

params = load_params();

shapes = {'./data/0001.isometry.4.off', ...
    './data/0001.holes.5.off', ...
    './data/0001.sampling.5.off'};

titles = {'isometry', 'partiality', 'downsampling'};

% initialize pool for parallel k-means
delete(gcp);
parpool(4);

figure

for s=1:length(shapes)
    
    fprintf('-----------------------------\n');
    
    M = load_shape(shapes{s}, params);
    params.min_area = sum(M.S_tri)*0.1/100;
    
    segM = consensus_segment(M, params);
    
    subplot(1,3,s),
    plot_scalar_map_tri(M, segM); light; lighting phong; camlight head; axis off
    title(titles{s})
    
end
