function M = load_shape(fname, params)

fprintf('Loading mesh %s... ', fname);

M = loadoff(fname);

if size(M.VERT,1) > 1e4
    M = remesh(M, struct('verbose',false,'vertices',1e4));
end

M.n = size(M.VERT,1);
M.m = size(M.TRIV,1);

[M.evecs, M.evals, M.S] = calc_LB(M, params.max_eigen);

% compute projection operator from vertices to triangles
rows = kron((1:M.m)',ones(3,1));
cols = reshape(M.TRIV',3*M.m,1);
M.proj = sparse(rows,cols,1/3,M.m,M.n);

% compute exact triangle areas
M.S_tri = zeros(M.m,1);
for i=1:M.m
    e1 = M.VERT(M.TRIV(i,3),:) - M.VERT(M.TRIV(i,1),:);
    e2 = M.VERT(M.TRIV(i,2),:) - M.VERT(M.TRIV(i,1),:);
    M.S_tri(i) = 0.5*norm(cross(e1,e2));
end

fprintf('done.\n');

end
